==> retrodevem-0.2.tar.gz: retrodevem-0.2/doc/sourcing.md <==
# Sourcing

Everything was found on Farnell, except the plexiglass.  The prices
are in Euros.

## Connectors and components

- 2x 2x5  Pin Headers
- 1x 2x20 PCB Receptacle / Socket
- 14x 15 KOhms resitors
- 2x ULN2003AN

| Count | Reference                   | Description       | Unit Price(+) | Total Price |
|-------|-----------------------------|-------------------|---------------|-------------|
| 2     | Multicomp Pro 2213S-10G     | 2x5 Pin Header    | 0.085         | 0.17        |
| 1     | Multicomp Pro 2214S-40SG-85 | 2x20 PCB Socket   | 1.45          | 1.45        |
| 14    | Multicomp Pro MP006750      | 15 KOhms resistor | 0.021         | 0.294       |
| 2     | Texas Instruments ULN2003AN | Transistors Array | 0.392         | 0.784       |
|       |                             | Total             |               | 2.698       |

(+) On Farnell

## Standoffs and feet

| Count | Reference              | Description                  | Unit Price(+) | Total Price |
|-------|------------------------|------------------------------|---------------|-------------|
| 4     | Ettinger 005.02.113    | female/female M2.5 11mm      | 0.312         | 1.248       |
| 4     | Ettinger 005.12.083    | male/female M2.5, 8mm, 14mm  | 0.307         | 1.228       |
| 4     | Ettinger 005.12.173    | male/female M2.5, 17mm, 23mm | 0.384         | 1.536       |
| 4     | Ettinger 017.52.080    | foot round 2.8mm * 8mm       | 0.30          | 1.2         |
| 8     | Multicomp Pro MP007339 | vis M2.5 6mm                 | 0.10(++)      | 0.8         |
|       |                        | Total                        |               | 6.012       |

(+) On Farnell
(++) Lot of 50 for 5.01 E (/ 5.01 50)

## Cables

- 2x 40 cm ribbon cable
- 2x DB9 connector (Plastic)
- 2x IDC connector

| Count | Reference                     | Description   | Unit Price(+) | Total Price |
|-------|-------------------------------|---------------|---------------|-------------|
| 80 cm | Multicomp Pro R2651DTSY10SC85 | Ribbon cable  | 1.18          | 0.094       |
| 2     | Amphenol L17DEFRB09S          | DB9 connector | 3.53          | 7.06        |
| 2     | Amphenol T812110A101CEU       | IDC connector | 0.293         | 0.586       |
|       |                               | Total         |               | 7.740       |

## Plexiglass

2mm transparent plexiglass plate (on Amazon) for a few Euros.

==> retrodevem-0.6.tar.gz: retrodevem-0.6/doc/sourcing.md <==
# Sourcing

Everything was found on Farnell, except the plexiglass.  The prices
are in Euros.

## Connectors and components

- 2x 2x5  Pin Headers
- 1x 2x20 PCB Receptacle / Socket
- 14x 15 KOhms resitors
- 2x ULN2003AN

| Count | Reference                   | Description       | Unit Price(+) | Total Price |
|-------|-----------------------------|-------------------|---------------|-------------|
| 2     | Multicomp Pro 2213S-10G     | 2x5 Pin Header    | 0.085         | 0.17        |
| 1     | Multicomp Pro 2214S-40SG-85 | 2x20 PCB Socket   | 1.45          | 1.45        |
| 14    | Multicomp Pro MP006750      | 15 KOhms resistor | 0.021         | 0.294       |
| 2     | Texas Instruments ULN2003AN | Transistors Array | 0.392         | 0.784       |
|       |                             | Total             |               | 2.698       |

(+) On Farnell

## Standoffs and feet

| Count | Reference              | Description                  | Unit Price(+) | Total Price |
|-------|------------------------|------------------------------|---------------|-------------|
| 4     |                        | female/female M2.5, 12mm     |               |             |
| 8     | Ettinger 005.12.103    | male/female M2.5, 10mm, 16mm | 0.319         | 2.55        |
| 4     | Ettinger 017.52.080    | foot round 2.8mm * 8mm       | 0.30          | 1.2         |
| 8     | Multicomp Pro MP007339 | vis M2.5 6mm                 | 0.10(++)      | 0.8         |
|       |                        | Total                        |               |             |

(+) On Farnell
(++) Lot of 50 for 5.01 E (/ 5.01 50)

## Cables

- 2x 40 cm ribbon cable
- 2x DB9 connector (Plastic)
- 2x IDC connector

| Count | Reference                     | Description   | Unit Price(+) | Total Price |
|-------|-------------------------------|---------------|---------------|-------------|
| 80 cm | Multicomp Pro R2651DTSY10SC85 | Ribbon cable  | 1.18          | 0.094       |
| 2     | Amphenol L17DEFRB09S          | DB9 connector | 3.53          | 7.06        |
| 2     | Amphenol T812110A101CEU       | IDC connector | 0.293         | 0.586       |
|       |                               | Total         |               | 7.740       |

## Plexiglass

2mm transparent plexiglass plate (on Amazon) for a few Euros.
